DenoiseResult class

Result of adaptive denoising operation.

Constructors

DenoiseResult({required Uint8List bytes, required int width, required int height, required String strategy, required double estimatedLuminosity, required double estimatedNoise})
const

Properties

bytes → Uint8List
Denoised image bytes.
final
estimatedLuminosity → double
Estimated image luminosity (0.0–1.0).
final
estimatedNoise → double
Estimated noise level (0.0–1.0).
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
Image height.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strategy → String
Name of the denoising strategy applied.
final
width → int
Image width.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited