PerspectiveWarpResult class

Result of perspective warp operation.

Constructors

PerspectiveWarpResult({required Uint8List bytes, required int width, required int height, required Float64List homography, required DocumentCorners sourceCorners})
const

Properties

bytes → Uint8List
Warped (flattened) grayscale image bytes.
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
Output image height.
final
homography → Float64List
The 3×3 homography matrix used for the warp.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceCorners → DocumentCorners
Original source document corners.
final
width → int
Output image width.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited