PreprocessingMetrics class

Image quality metrics after preprocessing.

Constructors

PreprocessingMetrics({required double luminosity, required double blurScore, required double contrastScore, double noiseLevel = 0.0})
const

Properties

blurScore → double
Updated blur score after sharpening.
final
contrastScore → double
Updated contrast score after enhancement.
final
hashCode → int
The hash code for this object.
no setterinherited
luminosity → double
Updated luminosity after enhancement.
final
noiseLevel → double
Estimated noise level (0.0–1.0).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited