ParserValidation class

Detailed validation result from a ResultParser.

Constructors

ParserValidation({required bool isValid, required double confidence, Map<String, FieldValidation> fieldValidations = const {}, String summary = '', List<String> warnings = const [], List<String> errors = const []})
const
ParserValidation.failed({required List<String> errors, double confidence = 0.0, Map<String, FieldValidation>? fields})
Creates a failing validation result.
factory
ParserValidation.passed({double confidence = 1.0, Map<String, FieldValidation>? fields})
Creates a passing validation result.
factory

Properties

confidence → double
Overall confidence (0.0–1.0).
final
errors → List<String>
List of validation errors (critical failures).
final
fieldValidations → Map<String, FieldValidation>
Per-field validation results.
final
hashCode → int
The hash code for this object.
no setterinherited
isValid → bool
Overall validation passed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
summary → String
Human-readable validation summary.
final
warnings → List<String>
List of validation warnings (non-critical issues).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited