isReady property
bool
get
isReady
Whether this detector is initialized and ready to process frames.
Implementation
bool get isReady;
Whether this detector is initialized and ready to process frames.
bool get isReady;