PreprocessingStrategy class

Preprocessing strategy configuration.

Constructors

PreprocessingStrategy({bool enableContrastEnhancement = false, bool enableBinarization = false, BinarizationType binarizationType = BinarizationType.otsu, bool enableNoiseReduction = false, double noiseReductionStrength = 0.5, bool enableEdgeDetection = false, bool enableSharpening = false, double sharpeningAmount = 1.0, bool enableGammaCorrection = false, double gamma = 0.6})
const

Properties

binarizationType → BinarizationType
Binarization algorithm to use.
final
enableBinarization → bool
Whether to apply image binarization.
final
enableContrastEnhancement → bool
Whether to apply contrast enhancement (CLAHE/histogram equalization).
final
enableEdgeDetection → bool
Whether to apply edge detection.
final
enableGammaCorrection → bool
Whether to apply gamma correction.
final
enableNoiseReduction → bool
Whether to apply noise reduction.
final
enableSharpening → bool
Whether to apply sharpening (unsharp mask).
final
gamma → double
Gamma value for correction.
final
hashCode → int
The hash code for this object.
no setterinherited
noiseReductionStrength → double
Noise reduction strength (0.0–1.0).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharpeningAmount → double
Sharpening amount (0.5–2.0).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited