autoTorchInLowLight property
Automatically switch flashlight on when ambient light drops below threshold.
Implementation
final bool autoTorchInLowLight;
Automatically switch flashlight on when ambient light drops below threshold.
final bool autoTorchInLowLight;