enableAutoCapture property
Whether enterprise document auto capture is enabled when quality threshold is met.
Implementation
final bool enableAutoCapture;
Whether enterprise document auto capture is enabled when quality threshold is met.
final bool enableAutoCapture;