frameThrottleMs property
Minimum delay in milliseconds between consecutive frame analysis passes. (e.g. 50ms = max 20 detections/sec for optimal CPU & battery usage).
Implementation
final int frameThrottleMs;
Minimum delay in milliseconds between consecutive frame analysis passes. (e.g. 50ms = max 20 detections/sec for optimal CPU & battery usage).
final int frameThrottleMs;