droppedFrames property
Total count of frames skipped due to throttling, blur, or static scene detection.
Implementation
final int droppedFrames;
Total count of frames skipped due to throttling, blur, or static scene detection.
final int droppedFrames;