AadhaarParser class

Indian Aadhaar Card Verhoeff D10 checksum and Secure XML/OCR/Binary QR parser.

Constructors

AadhaarParser()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isAadhaarPayload(String rawData) bool
Detects whether raw QR string or byte payload represents an Aadhaar QR code.
parse(String rawData) ScanResult
Parses raw text, Secure QR XML, or compressed binary payload from an Aadhaar card.
validateAadhaarVerhoeff(String number) bool
Validates a 12-digit Indian Aadhaar number using the Verhoeff algorithm.