BankChequeInfo class

Data structure holding parsed details from a Bank Cheque MICR codeline.

Constructors

BankChequeInfo({required String rawMicrLine, required String chequeNumber, required String routingNumber, required String accountNumber, required String transactionCode, String? bankName, String? ifscCode, String? chequeDate, double? amount, required bool isValidMicr, Map<String, String> extraDetails = const {}})
const
BankChequeInfo.fromJson(Map<String, dynamic> json)
factory

Properties

accountNumber String
final
amount double?
final
bankName String?
final
chequeDate String?
final
chequeNumber String
final
extraDetails Map<String, String>
final
hashCode int
The hash code for this object.
no setterinherited
ifscCode String?
final
isValidMicr bool
final
rawMicrLine String
final
routingNumber String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transactionCode String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFields() Map<String, String>
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited