BankChequeParser class

Offline vision AI parser for Bank Cheques and E-13B / CMC-7 MICR codelines.

Constructors

BankChequeParser()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(String rawText) BankChequeInfo
Parses raw text extracted from bank cheque OCR scan into BankChequeInfo.
validateRoutingChecksum(String routingStr) bool
ABA Routing Number Modulo 10 Checksum Algorithm (Weighting 3, 7, 1).