BusinessCardParser class

Specialized Business Card OCR parser extracting person name, title, company, phone numbers, email address, website URL, and physical address.

Constructors

BusinessCardParser()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(String rawText) ScanResult
Parses raw OCR text extracted from a business card image.