Gs1BarcodeParser class

Dynamic GS1 Application Identifier (AI) & Custom Barcode Payload Parser

Constructors

Gs1BarcodeParser()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(String rawValue) ScanResult
Parse GS1 payload or dynamic text into a structured ScanResult
parseGs1Payload(String rawValue) Map<String, String>
Dynamically parses GS1 AIs, key-value pairs, and heuristic patterns