ScannerPluginRegistry class

Central registry managing custom active scanner plugins.

Constructors

ScannerPluginRegistry()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

allPlugins List<ScannerPlugin>
List of all currently registered plugin instances.
no setter

Static Methods

clear() → void
Clears all registered plugins.
findForMode(ScanMode mode) ScannerPlugin?
Retrieves a registered plugin matching the specified ScanMode.
register(ScannerPlugin plugin) → void
Registers a new ScannerPlugin.
unregister(String pluginId) → void
Unregisters a plugin by its ID.