FrameEntry class

Single frame entry in the ring buffer.

Constructors

FrameEntry({required Uint8List bytes, required int width, required int height, required DateTime timestamp, required int sequenceNumber, int frameHash = 0})
const

Properties

bytes → Uint8List
Raw frame bytes (typically Y-plane grayscale).
final
frameHash → int
Lightweight hash for duplicate frame detection.
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
Frame height.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber → int
Frame sequence number.
final
timestamp → DateTime
Timestamp when the frame was captured.
final
width → int
Frame width.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited