MergedOcrResult class

Result of multi-pass OCR merging.

Constructors

MergedOcrResult({required String text, required double confidence, required List<double> blockConfidences, required int passesUsed, required String mergeStrategy})
const

Properties

blockConfidences List<double>
Per-block/line confidence scores.
final
confidence double
Overall merged confidence (0.0–1.0).
final
hashCode int
The hash code for this object.
no setterinherited
mergeStrategy String
Name of the merge strategy applied.
final
passesUsed int
Number of OCR passes used in merging.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
Merged best-confidence text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited