PostProcessResult class

Result of post-processing.

Constructors

PostProcessResult({required String text, required List<String> corrections, required double confidenceAdjustment})
const

Properties

confidenceAdjustment double
Confidence adjustment (negative = reduced confidence).
final
corrections List<String>
List of corrections applied.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
Corrected/normalized text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited