CloudSyncAdapter class abstract

Abstract cloud sync adapter interface.

Implement this interface to integrate with any cloud storage provider (Firebase, AWS S3, Supabase, custom REST APIs, etc).

Implementers

Constructors

CloudSyncAdapter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String id) Future<bool>
Deletes a scan result from cloud storage by ID.
download({DateTime? since}) Future<List<ScanResult>>
Downloads scan results from cloud storage.
isAvailable() Future<bool>
Checks connectivity / health of the cloud endpoint.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upload(ScanResult result, {Map<String, String>? metadata}) Future<bool>
Uploads a single scan result to cloud storage.

Operators

operator ==(Object other) bool
The equality operator.
inherited