DocumentClassifier class

AI-powered & heuristic document classifier analyzing OCR text patterns, structural keyphrases, and payload signatures.

Constructors

DocumentClassifier()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

classify(String rawText, {Map<String, String>? fields, ScanMode? mode}) DocumentClassificationResult
Classifies OCR raw text or scan result into a DocumentCategory.