EncryptionException class

Exception thrown when encryption or decryption operations fail.

Implemented types

Constructors

EncryptionException(String message)
Constructs an EncryptionException with the given message.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
Error description message.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited