JsonExporter class

Serializes batch scan results or history logs into structured JSON format.

Constructors

JsonExporter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

exportToJson(List<ScanResult> results, {bool prettyPrint = true}) String
Exports list of ScanResult items to formatted JSON string.
importFromJson(String jsonString) List<ScanResult>
Parses a JSON string back into a list of ScanResult items.