resultStream property
Stream<ScanResult>
get
resultStream
Stream of new scan results added to this session.
Implementation
Stream<ScanResult> get resultStream => _resultStreamController.stream;
Stream of new scan results added to this session.
Stream<ScanResult> get resultStream => _resultStreamController.stream;