SessionState enum

Session lifecycle state.

Inheritance
Available extensions

Values

idle → const SessionState

Session has not started.

active → const SessionState

Session is actively scanning.

paused → const SessionState

Session is temporarily paused.

completed → const SessionState

Session has been completed.

cancelled → const SessionState

Session was cancelled without saving.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SessionState>
A constant List of the values in this enum, in order of their declaration.