LightCondition enum

Light condition assessment for scan environment.

Inheritance
Available extensions

Values

tooLow → const LightCondition

Ambient lighting is too dark for reliable scanning.

low → const LightCondition

Low but potentially usable lighting.

normal → const LightCondition

Normal indoor or outdoor lighting.

bright → const LightCondition

Bright, well-lit environment.

overexposed → const LightCondition

Overexposed — too much light causing glare/washout.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LightCondition>
A constant List of the values in this enum, in order of their declaration.