WatermarkPosition enum

Position presets for watermark placement on scan images.

Inheritance
Available extensions

Values

center → const WatermarkPosition

Centered on the image.

topLeft → const WatermarkPosition

Top-left corner with padding.

topRight → const WatermarkPosition

Top-right corner with padding.

bottomLeft → const WatermarkPosition

Bottom-left corner with padding.

bottomRight → const WatermarkPosition

Bottom-right corner with padding.

tiled → const WatermarkPosition

Tiled across the entire image surface.

diagonal → const WatermarkPosition

Diagonal across the image center (rotated 45°).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<WatermarkPosition>
A constant List of the values in this enum, in order of their declaration.