IsolateFrameResult class

Structured response output returned from isolate frame processing.

Constructors

IsolateFrameResult({required Uint8List processedBytes, required double averageLuminosity, required int croppedWidth, required int croppedHeight, required bool isLowLight, double blurScore = 100.0, bool isBlurry = false, bool isMotionDetected = false, double motionScore = 0.0, bool isStaticFrame = false, int frameHash = 0, double contrastScore = 1.0, List<String> enhancementsApplied = const [], required DocumentQualityScore qualityScore, double tenengradScore = 0.0, double glareRatio = 0.0, List<String> processingPipeline = const []})
const

Properties

averageLuminosity → double
final
blurScore → double
final
contrastScore → double
final
croppedHeight → int
final
croppedWidth → int
final
enhancementsApplied → List<String>
final
frameHash → int
final
glareRatio → double
v3.0: Fraction of hot/glare pixels (0.0–1.0).
final
hashCode → int
The hash code for this object.
no setterinherited
isBlurry → bool
final
isLowLight → bool
final
isMotionDetected → bool
final
isStaticFrame → bool
final
motionScore → double
final
processedBytes → Uint8List
final
processingPipeline → List<String>
v3.0: Ordered list of processing steps applied.
final
qualityScore → DocumentQualityScore
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tenengradScore → double
v3.0: Tenengrad sharpness score (higher = sharper).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited