SampleCardPresets class

Container class for preset sample card scan items.

Constructors

SampleCardPresets()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getSamplesForMode(ScanMode mode) List<SampleItem>
Returns sample items available for a specific ScanMode.
processSample(SampleItem sample) ScanResult