SampleItem class

Represents a single sample payload item used for mode demonstration.

Constructors

SampleItem({required String label, required String payload, required ScanMode mode})
Constructs a new SampleItem.

Properties

hashCode → int
The hash code for this object.
no setterinherited
label → String
User-facing label for the sample.
final
mode → ScanMode
The associated ScanMode.
final
payload → String
The raw payload text of the sample.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited