ScanbotBarcodeScannerConfig class

Configuration options for Scanbot SDK barcode scanner UI.

Constructors

ScanbotBarcodeScannerConfig({List<String>? barcodeFormats, bool enableBatchScan = false, int? maxBatchCount})
const

Properties

barcodeFormats → List<String>?
final
enableBatchScan → bool
final
hashCode → int
The hash code for this object.
no setterinherited
maxBatchCount → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited