didChangeAppLifecycleState method
Called when the system puts the app in the background or returns the app to the foreground.
An example of implementing this method is provided in the class-level documentation for the WidgetsBindingObserver class.
This method exposes notifications from SystemChannels.lifecycle.
See also:
- AppLifecycleListener, an alternative API for responding to application lifecycle changes.
Implementation
@override
void didChangeAppLifecycleState(AppLifecycleState state) {
if (_isDisposed ||
_cameraController == null ||
!_cameraController!.value.isInitialized) {
return;
}
if (state == AppLifecycleState.inactive ||
state == AppLifecycleState.paused) {
pauseScanning();
} else if (state == AppLifecycleState.resumed) {
resumeScanning();
}
}