historyController property
Dedicated scan history controller for recording, searching, and exporting scan results.
Implementation
late final ScanHistoryController historyController;
Dedicated scan history controller for recording, searching, and exporting scan results.
late final ScanHistoryController historyController;