isLowLight property
bool
get
isLowLight
Whether camera scene is currently under low ambient lighting.
Implementation
bool get isLowLight => _isLowLight;
Whether camera scene is currently under low ambient lighting.
bool get isLowLight => _isLowLight;