removeBatchItem method
Removes an item from batch scan list by index.
Implementation
void removeBatchItem(int index) {
if (index >= 0 && index < _batchResults.length) {
_batchResults.removeAt(index);
_safeNotifyListeners();
}
}
Removes an item from batch scan list by index.
void removeBatchItem(int index) {
if (index >= 0 && index < _batchResults.length) {
_batchResults.removeAt(index);
_safeNotifyListeners();
}
}