scanImage method
Scans a local image file directly from a File object.
Implementation
Future<ScanResult> scanImage(File imageFile, {ScanMode? mode}) async {
return await processImageFile(imageFile.path, mode: mode);
}
Scans a local image file directly from a File object.
Future<ScanResult> scanImage(File imageFile, {ScanMode? mode}) async {
return await processImageFile(imageFile.path, mode: mode);
}