ScannerOverlayPainter class

Custom painter for camera viewfinder cutout, reticle corners, tap-to-focus ring, detection highlight flash, and animated laser beam.

Inheritance

Constructors

ScannerOverlayPainter({required ScanMode scanMode, required double animationValue, Color accentColor = const Color(0xFF00E5FF), ScannerUiTheme? theme, Offset? focusPoint, bool isDetected = false, Rect? detectedBoundingBox, Rect? customScanArea, List<Rect>? multiBoundingBoxes})
Constructs a new ScannerOverlayPainter.

Properties

accentColor Color
Accent highlight color.
final
animationValue double
Animated progress value from 0.0 to 1.0.
final
customScanArea Rect?
Custom explicit scan rectangle area cutout.
final
detectedBoundingBox Rect?
Detected target bounding box rectangle relative to screen coordinates.
final
focusPoint Offset?
User tap-to-focus point coordinates relative to overlay viewport.
final
hashCode int
The hash code for this object.
no setterinherited
isDetected bool
Whether a valid barcode or document frame was detected in current frame pass.
final
multiBoundingBoxes List<Rect>?
List of bounding boxes for multiple detected codes.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scanMode ScanMode
Active scanning mode.
final
semanticsBuilder SemanticsBuilderCallback?
Returns a function that builds semantic information for the picture drawn by this painter.
no setterinherited
theme ScannerUiTheme?
Optional custom UI design theme configuration.
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be notified when it is time to repaint.
inherited
hitTest(Offset position) bool?
Called whenever a hit test is being performed on an object that is using this custom paint delegate.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size) → void
Called whenever the object needs to paint. The given Canvas has its coordinate space configured such that the origin is at the top left of the box. The area of the box is the size of the size argument.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies when it is time to repaint.
inherited
shouldRebuildSemantics(covariant CustomPainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
inherited
shouldRepaint(covariant ScannerOverlayPainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited