TrackedBarcode class
Representation of a detected barcode within a video frame or image.
Constructors
Properties
- boundingBox → Rect
-
final
-
corners
→ List<
Offset> -
final
- firstDetectedTime → DateTime
-
final
- format → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hitCount → int
-
final
- id → String
-
final
- lastSeenTime → DateTime
-
final
- rawValue → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Rect? boundingBox, List< Offset> ? corners, DateTime? lastSeenTime, int? hitCount}) → TrackedBarcode -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited