EdgeDetectionResult class

Result of edge detection with statistics.

Constructors

EdgeDetectionResult({required Uint8List edges, required int width, required int height, required int edgePixelCount, required double edgeDensity})
const

Properties

edgeDensity double
Edge density (edge pixels / total pixels, range 0.0–1.0).
final
edgePixelCount int
Total number of edge pixels detected.
final
edges Uint8List
Binary edge map (0 or 255 per pixel).
final
hashCode int
The hash code for this object.
no setterinherited
height int
Image height.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
Image width.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited