AdaptivePreprocessResult class
Result of multi-pass adaptive preprocessing.
Constructors
-
AdaptivePreprocessResult({required Uint8List bytes, required int width, required int height, required List<
String> stepsApplied, required double originalBlurScore, required double enhancedBlurScore, required double originalLuminosity, required double enhancedLuminosity, required double originalContrast, required double enhancedContrast}) -
const
Properties
- bytes → Uint8List
-
Processed grayscale image bytes.
final
- enhancedBlurScore → double
-
Blur score after enhancement.
final
- enhancedContrast → double
-
Contrast after enhancement.
final
- enhancedLuminosity → double
-
Luminosity after enhancement.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
Image height.
final
- originalBlurScore → double
-
Blur score before enhancement.
final
- originalContrast → double
-
Contrast before enhancement.
final
- originalLuminosity → double
-
Luminosity before enhancement.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stepsApplied
→ List<
String> -
Ordered list of preprocessing steps applied.
final
- width → int
-
Image width.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited