PreprocessedFrame class
Result of frame preprocessing.
Constructors
-
PreprocessedFrame({required Uint8List bytes, required int width, required int height, required String strategyName, List<
String> stepsApplied = const [], required PreprocessingMetrics metrics}) -
const
Properties
- bytes → Uint8List
-
Processed grayscale image bytes.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
Image height (may differ from input if resized).
final
- metrics → PreprocessingMetrics
-
Updated image metrics after preprocessing.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stepsApplied
→ List<
String> -
Ordered list of processing steps applied.
final
- strategyName → String
-
Name of the preprocessing strategy applied.
final
- width → int
-
Image width (may differ from input if resized).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited