FieldValidation class
Validation result for a single parsed field.
Constructors
Properties
- confidence → double
-
Confidence for this field (0.0–1.0).
final
- correctedValue → String?
-
The validated/corrected value (may differ from raw value after OCR correction).
final
- fieldName → String
-
Field name.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isValid → bool
-
Whether this field passed validation.
final
- message → String
-
Validation message.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- validationMethod → String
-
Validation method used (e.g., 'checksum', 'regex', 'lookup', 'length').
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited