DetectionConfig class
Detection backend configuration.
Constructors
Properties
- enableMultiScale → bool
-
Whether to use multi-scale detection.
final
- enableRotationRetry → bool
-
Whether to try rotated variants if initial detection fails.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxRetries → int
-
Maximum number of detection attempts per frame.
final
-
rotationAngles
→ List<
int> -
Rotation angles to try (degrees).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited