PostProcessingConfig class
Post-processing configuration.
Constructors
- PostProcessingConfig({bool enableOcrCorrections = true, bool enableWhitespaceNormalization = true, bool recalculateConfidence = true, bool enableModeSpecificProcessing = true})
-
const
Properties
- enableModeSpecificProcessing → bool
-
Whether to apply mode-specific post-processing.
final
- enableOcrCorrections → bool
-
Whether to apply OCR error corrections.
final
- enableWhitespaceNormalization → bool
-
Whether to apply whitespace normalization.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- recalculateConfidence → bool
-
Whether to recalculate confidence after corrections.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited