TextElement class

Individual text element inside an OCR line.

Constructors

TextElement({required String text, double confidence = 1.0, Rect? boundingBox, String? recognizedLanguage})
const
TextElement.fromJson(Map<String, dynamic> json)
factory

Properties

boundingBox Rect?
Bounding box rectangle in image pixel coordinates.
final
confidence double
Detection confidence score (0.0 to 1.0).
final
hashCode int
The hash code for this object.
no setterinherited
recognizedLanguage String?
Recognized language BCP-47 tag (e.g. 'en', 'hi', 'es').
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The recognized text string for this word or element.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited