BarcodeResult class
Detailed result structure for individual detected barcodes in multi-barcode scanning mode.
- Annotations
Constructors
Properties
- boundingBox → Rect?
-
final
-
corners
→ List<
Offset> ? -
final
- displayValue → String?
-
final
- format → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- rawBytes → Uint8List?
-
final
- rawValue → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited