DocumentQualityScore class

Document image quality metrics calculated during isolate preprocessing.

Annotations

Constructors

DocumentQualityScore({required double blurScore, required double brightnessScore, required double contrastScore, required double overallQuality, required bool isHighQuality})
const
DocumentQualityScore.fromJson(Map<String, dynamic> json)
factory

Properties

blurScore double
final
brightnessScore double
final
contrastScore double
final
hashCode int
The hash code for this object.
no setterinherited
isHighQuality bool
final
overallQuality double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited