ScanMode enum

Supported scanning modes in Universal Scanner Pro.

Inheritance
Available extensions

Values

qr → const ScanMode

QR Code scanning mode (URLs, vCard, WiFi, UPI, Geo).

barcode → const ScanMode

1D Retail and logistics barcode scanning mode (EAN, UPC, Code128).

pdf417 → const ScanMode

PDF417 stacked 2D barcode scanning mode.

passport → const ScanMode

Passport MRZ (Machine Readable Zone) scanning mode.

aadhaar → const ScanMode

Indian Aadhaar Card Secure QR & OCR mode.

pan → const ScanMode

Income Tax PAN Card OCR mode.

drivingLicense → const ScanMode

Driving License PDF417 & OCR mode.

vin → const ScanMode

ISO 3779 17-character VIN number mode.

ocr → const ScanMode

General OCR text recognition mode.

face → const ScanMode

Face detection & landmark analysis mode.

document → const ScanMode

Auto Document Edge Detection, Quad Cropping & Perspective Correction mode.

invoice → const ScanMode

Invoice and Bill OCR text recognition parser.

receipt → const ScanMode

Store Receipt OCR text recognition parser.

businessCard → const ScanMode

Business Card Contact OCR parser.

multiCode → const ScanMode

Multi-Code simultaneous QR and 1D/2D Barcode scanner mode.

Properties

category String

Available on ScanMode, provided by the ScanModeExtension extension

High-level category grouping for this scan mode.
no setter
guideText String

Available on ScanMode, provided by the ScanModeExtension extension

Guidance text displayed over camera viewfinder for this mode.
no setter
hashCode int
The hash code for this object.
no setterinherited
icon IconData

Available on ScanMode, provided by the ScanModeExtension extension

The icon representing this mode.
no setter
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String

Available on ScanMode, provided by the ScanModeExtension extension

The user-facing subtitle description for this mode.
no setter
targetAspectRatio double

Available on ScanMode, provided by the ScanModeExtension extension

Target aspect ratio (width / height) for camera reticle cutout.
no setter
title String

Available on ScanMode, provided by the ScanModeExtension extension

The user-facing display title for this mode.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ScanMode>
A constant List of the values in this enum, in order of their declaration.