ScannerFpsState enum
State representing camera frame processing activity level.
- Inheritance
- Available extensions
Values
- searching → const ScannerFpsState
-
Active searching state for codes/documents (30 FPS / ~33ms).
- detected → const ScannerFpsState
-
Target code/document detected (15 FPS / ~66ms).
- idle → const ScannerFpsState
-
Idle / low-activity state (10 FPS / ~100ms).
Properties
- frameIntervalMs → int
-
Available on ScannerFpsState, provided by the ScannerFpsStateExtension extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetFps → int
-
Available on ScannerFpsState, provided by the ScannerFpsStateExtension extension
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ScannerFpsState> - A constant List of the values in this enum, in order of their declaration.