InvoiceParser class
Specialized Invoice / Bill OCR document parser extracting total amount, subtotal, tax/VAT/GST, invoice number, invoice date, due date, vendor details, and line item previews.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parse(
String rawText) → ScanResult - Parses raw text extracted from an invoice or bill image.