PanCardParser class

Indian Income Tax PAN (Permanent Account Number) Card parser & fuzzy OCR engine.

Constructors

PanCardParser()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getCategoryName(String statusChar) String
Decodes 4th character status code to Taxpayer Category name.
parse(String rawText) ScanResult
Parses raw text input into a structured PAN card ScanResult.