ReceiptParser class

Specialized Receipt OCR document parser extracting total amount, date, tax, merchant name, and line item preview details.

Constructors

ReceiptParser()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(String rawText) ScanResult
Parses raw text extracted from a receipt image.