VinParser class
ISO 3779 17-character Vehicle Identification Number (VIN) parser and check digit verifier.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
calculateCheckDigit(
String vin) → String - Calculates the Position 9 check digit for a 17-character VIN.
-
decodeModelYear(
String pos10) → String - Decodes Position 10 character into vehicle model year range.
-
parse(
String rawText) → ScanResult - Parses raw text into a vehicle VIN ScanResult.