SyncQueueStats class
Sync queue statistics snapshot.
Constructors
Properties
- completionRate → double
-
Sync completion percentage (0.0 to 1.0).
no setter
- conflicts → int
-
Items with sync conflicts.
final
- failed → int
-
Failed items awaiting retry.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFullySynced → bool
-
Whether all items have been successfully synced.
no setter
- pending → int
-
Items pending upload.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- synced → int
-
Successfully synced items.
final
- total → int
-
Total items in the sync queue.
final
- uploading → int
-
Items currently uploading.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited