DocumentClassificationResult class
Represents the classification output for a scanned document.
Constructors
-
DocumentClassificationResult({required DocumentCategory category, required double confidence, required List<
String> detectedKeywords, required String description}) -
const
Properties
- category → DocumentCategory
-
final
- confidence → double
-
final
- description → String
-
final
-
detectedKeywords
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited