DocumentCorners class
Data structure representing detected document quad bounds.
Constructors
- DocumentCorners({required Offset topLeft, required Offset topRight, required Offset bottomRight, required Offset bottomLeft})
-
const
Properties
- bottomLeft → Offset
-
final
- bottomRight → Offset
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topLeft → Offset
-
final
- topRight → Offset
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBoundingBox(
) → Rect -
toList(
) → List< Offset> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited