FeedbackService class
Manages audio beep and haptic feedback triggers upon scan detection events.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
playFailureFeedback(
{bool sound = true, bool vibration = true}) → Future< void> - Emits failure/error feedback (heavy haptic vibration).
-
playSuccessFeedback(
{bool sound = true, bool vibration = true}) → Future< void> - Emits success feedback (light/medium haptic vibration & system sound).