CompressionPreset enum
Compression quality preset levels for image output.
- Inheritance
- Available extensions
Values
- ultraHigh → const CompressionPreset
-
Minimal compression, highest quality (~95% retention).
- high → const CompressionPreset
-
Standard high quality compression (~85% retention).
- medium → const CompressionPreset
-
Balanced quality vs size compression (~70% retention).
- low → const CompressionPreset
-
Aggressive compression for minimal file sizes (~50% retention).
- thumbnail → const CompressionPreset
-
Maximum compression with visible quality loss (~30% retention).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
Available on CompressionPreset, provided by the CompressionPresetExtension extension
Human-readable label for this compression preset.no setter - name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - qualityFactor → double
-
Available on CompressionPreset, provided by the CompressionPresetExtension extension
Quality factor from 0.0 to 1.0 for this preset.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CompressionPreset> - A constant List of the values in this enum, in order of their declaration.