CompressionResult class
Result of an image compression operation.
Constructors
Properties
- compressedBytes → Uint8List
-
Compressed image byte buffer.
final
- compressedSize → int
-
Final byte size after compression.
final
- compressionRatio → double
-
Compression ratio achieved (0.0 to 1.0, lower = more compressed).
final
- elapsed → Duration
-
Duration elapsed during compression.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- originalSize → int
-
Original byte size before compression.
final
- qualityUsed → double
-
Quality factor used during compression (0.0 to 1.0).
final
- reductionPercent → double
-
Size reduction percentage achieved (e.g. 45.2 means 45.2% smaller).
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- summary → String
-
Human-readable compression summary string.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited