SessionStats class
Statistics snapshot for a multi-scan session.
- Annotations
Constructors
Properties
- averageScanInterval → Duration?
-
Average time between consecutive scans.
final
- dominantMode → ScanMode?
-
Most frequently scanned mode.
final
- duplicatesFiltered → int
-
Number of duplicates detected and filtered.
final
- duration → Duration
-
Total session duration.
final
- endedAt → DateTime?
-
Session end or current timestamp.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- invalidScans → int
-
Number of invalid or failed scans.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startedAt → DateTime
-
Session start timestamp.
final
- successRate → double
-
Scan success rate (0.0 to 1.0).
final
- totalScans → int
-
Total number of items scanned in this session.
final
- validScans → int
-
Number of valid (successful) scans.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited