PdfExportUtil class

Constructors

PdfExportUtil()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

exportResultsToPdf({required List<ScanResult> results, String title = 'ScannerPro Scanned Document Export', String author = 'Universal Scanner Pro SDK', bool isLandscape = false, bool includeMetadata = true}) Uint8List
Compiles a list of ScanResult items or raw document images into PDF document bytes.