PdfExporter typedef
PdfExporter = PdfExportUtil
PDF Export utility compiling scan results and document pages into printable PDF documents.
Implementation
typedef PdfExporter = PdfExportUtil;
PDF Export utility compiling scan results and document pages into printable PDF documents.
typedef PdfExporter = PdfExportUtil;