BlurAnalysis class
Blur detection analysis results.
Constructors
- BlurAnalysis({required BlurSeverity severity, required double score, required double laplacianVariance})
-
const
-
BlurAnalysis.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSharp → bool
-
Whether the image is sharp enough for reliable scanning.
no setter
- laplacianVariance → double
-
Discrete Laplacian variance (higher = sharper).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- score → double
-
Blur score (0.0 = perfectly sharp, 1.0 = completely blurred).
final
- severity → BlurSeverity
-
Blur severity level.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited