ContrastAnalysis class
Contrast analysis results.
Constructors
- ContrastAnalysis({required double contrastRatio, required bool isAdequate, required int dynamicRange})
-
const
-
ContrastAnalysis.fromJson(Map<
String, dynamic> json) -
factory
Properties
- contrastRatio → double
-
Contrast ratio (higher = better separation between light and dark).
final
- dynamicRange → int
-
Dynamic range of pixel values (0-255 scale).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAdequate → bool
-
Whether contrast is adequate for scanning.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited