LightAnalysis class

Light condition analysis results.

Constructors

LightAnalysis({required LightCondition condition, required double averageLuminance, required double estimatedLux, required bool torchRecommended})
const
LightAnalysis.fromJson(Map<String, dynamic> json)
factory

Properties

averageLuminance double
Average luminance score (0.0 = pitch black, 1.0 = pure white).
final
condition LightCondition
Detected light condition.
final
estimatedLux double
Estimated lux level.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
torchRecommended bool
Whether torch/flash is recommended.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited