QualityGrade enum

Scan quality grade based on overall image analysis.

Inheritance
Available extensions

Values

excellent → const QualityGrade

Excellent quality — sharp, well-lit, properly aligned.

good → const QualityGrade

Good quality — minor issues that don't affect scanning.

acceptable → const QualityGrade

Acceptable quality — may affect recognition accuracy.

poor → const QualityGrade

Poor quality — likely to cause scan failures.

unusable → const QualityGrade

Unusable — image is too degraded for reliable scanning.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isAdequate bool

Available on QualityGrade, provided by the QualityGradeExtension extension

Whether this grade is adequate for reliable scanning.
no setter
label String

Available on QualityGrade, provided by the QualityGradeExtension extension

Human-readable label.
no setter
letterGrade String

Available on QualityGrade, provided by the QualityGradeExtension extension

Letter grade (A, B, C, D, F).
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<QualityGrade>
A constant List of the values in this enum, in order of their declaration.