SkewAnalysis class
Skew/tilt angle analysis results.
Constructors
- SkewAnalysis({required double angleDegrees, required bool isAligned, required double correctionAngle})
-
const
-
SkewAnalysis.fromJson(Map<
String, dynamic> json) -
factory
Properties
- angleDegrees → double
-
Detected skew angle in degrees.
final
- correctionAngle → double
-
Recommended correction angle in degrees (negative = rotate clockwise).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAligned → bool
-
Whether the document appears properly aligned (< 5° skew).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited