WatermarkResult class
Result of a watermark application operation.
Constructors
- WatermarkResult({required Uint8List watermarkedBytes, required int originalSize, required WatermarkConfig config, required bool success, required Duration elapsed})
-
const
Properties
- config → WatermarkConfig
-
Watermark configuration used.
final
- elapsed → Duration
-
Duration elapsed during watermark application.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- originalSize → int
-
Original image byte size.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
Whether the watermark was successfully applied.
final
- watermarkedBytes → Uint8List
-
Image bytes with watermark applied.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited