BenchmarkResult class

Micro-benchmark result snapshot metrics.

Constructors

BenchmarkResult({required String benchmarkName, required int totalRuns, required Duration totalDuration, required double opsPerSecond, required double averageLatencyMs, required double p95LatencyMs, required double memoryMbEstimate})
const

Properties

averageLatencyMs double
final
benchmarkName String
final
hashCode int
The hash code for this object.
no setterinherited
memoryMbEstimate double
final
opsPerSecond double
final
p95LatencyMs double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalDuration Duration
final
totalRuns int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited