ResultValidator class
Unified Result Validator suite for ScannerPro.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
validate(
ScanResult result) → ValidationResult - Validates a general ScanResult based on its detection format/mode.
-
validateAadhaar(
String rawInput) → ValidationResult - Validates 12-digit Indian Aadhaar number using the UIDAI Verhoeff D10 algorithm.
-
validateBarcode(
String barcode, {String? format}) → ValidationResult - Validates 1D/2D Retail and Logistics Barcodes (EAN-13, EAN-8, UPC-A, GS1).
-
validateDrivingLicense(
String rawInput) → ValidationResult - Validates Driving License (AAMVA or regional Indian DL).
-
validatePAN(
String rawInput) → ValidationResult - Validates Income Tax PAN Card (10-char alphanumeric sequence).
-
validatePassport(
String rawInput) → ValidationResult - Validates Passport MRZ 2-line or 3-line string (ICAO Doc 9303 standard).
-
validateQR(
String qrPayload) → ValidationResult - Validates QR Codes (URLs, UPI, vCard, WiFi).
-
validateVIN(
String rawInput) → ValidationResult - Validates 17-character Vehicle Identification Number (ISO 3779 standard).