ExternalLookupService class
Service providing real-time external REST API lookups for scan results.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
clearCache(
) → void - Clears the in-memory lookup cache.
-
fetchExternalDetails(
ScanResult result) → Future< Map< String, String> > - Performs asynchronous REST API lookups and returns extra metadata fields.