IsolateFrameResult class
Structured response output returned from isolate frame processing.
Constructors
-
IsolateFrameResult({required Uint8List processedBytes, required double averageLuminosity, required int croppedWidth, required int croppedHeight, required bool isLowLight, double blurScore = 100.0, bool isBlurry = false, bool isMotionDetected = false, double motionScore = 0.0, bool isStaticFrame = false, int frameHash = 0, double contrastScore = 1.0, List<
String> enhancementsApplied = const []}) -
const
Properties
- averageLuminosity → double
-
final
- blurScore → double
-
final
- contrastScore → double
-
final
- croppedHeight → int
-
final
- croppedWidth → int
-
final
-
enhancementsApplied
→ List<
String> -
final
- frameHash → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBlurry → bool
-
final
- isLowLight → bool
-
final
- isMotionDetected → bool
-
final
- isStaticFrame → bool
-
final
- motionScore → double
-
final
- processedBytes → Uint8List
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited