IsolateFrameTaskData class
Data structure carrying frame processing arguments into isolate task.
Constructors
- IsolateFrameTaskData({required Uint8List bytes, required int width, required int height, required int bytesPerRow, ScanWindow? scanWindow, bool computeLuminosity = true, bool enableEnhancement = true, bool enableBlurDetection = true, int? previousFrameHash})
-
const
Properties
- bytes → Uint8List
-
final
- bytesPerRow → int
-
final
- computeLuminosity → bool
-
final
- enableBlurDetection → bool
-
final
- enableEnhancement → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
final
- previousFrameHash → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scanWindow → ScanWindow?
-
final
- width → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited