ScanbotDocumentScannerConfig class
Configuration options for Scanbot SDK document scanner UI.
Constructors
- ScanbotDocumentScannerConfig({bool autoSnapping = true, double autoSnappingSensitivity = 0.85, DocumentFilterMode defaultFilter = DocumentFilterMode.original, bool enableMultiPage = true, int? maxPageCount})
-
const
Properties
- autoSnapping → bool
-
final
- autoSnappingSensitivity → double
-
final
- defaultFilter → DocumentFilterMode
-
final
- enableMultiPage → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxPageCount → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited