ScanbotSdk class
High-level facade mirroring Scanbot SDK package API patterns.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
applyFilterAndCrop(
Uint8List imageBytes, {required DocumentCorners corners, DocumentFilterMode filter = DocumentFilterMode.original, int width = 640, int height = 480}) → Uint8List -
Applies perspective crop and document enhancement filter to image bytes (
scanbot_sdkcropping API). -
createPdf(
List< DocumentPage> pages, {String title = 'Scanbot SDK Document Export', String? watermarkText, String? password}) → Uint8List -
Create a multi-page PDF document from scanned pages (
scanbot_sdkcreatePdf API). -
performOcr(
dynamic input, {List< String> ? languages}) → Future<ScanResult> -
Perform OCR text extraction (
scanbot_sdkperformOcr API). -
scanBarcode(
dynamic input, {ScanbotBarcodeScannerConfig config = const ScanbotBarcodeScannerConfig()}) → Future< ScanResult> -
Single or batch barcode scanner execution (
scanbot_sdkbarcode scanner). -
startDocumentScanner(
{ScanbotDocumentScannerConfig config = const ScanbotDocumentScannerConfig()}) → Future< DocumentScanSession> -
Start a document scanning flow (
scanbot_sdkdocument scanner).